AB.ModuleValidator (AB v0.2.1)
View SourceValidates all public functions in a module against their typespecs.
This module provides functionality to automatically test all exported functions in a module that have typespecs defined, ensuring comprehensive API validation.
Summary
Functions
Validates all public functions with typespecs in the given module.